# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKPDEDeformableRegistrationPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkDiffeomorphicDemonsRegistrationFilterPython
else:
    import _itkDiffeomorphicDemonsRegistrationFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkPDEDeformableRegistrationFilterPython
import itk.itkDenseFiniteDifferenceImageFilterPython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkFiniteDifferenceImageFilterPython
import itk.itkFiniteDifferenceFunctionPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterBPython

def itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_New():
    return itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22.New()

class itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF2IF2IVF22):
    r"""Proxy of C++ itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_GetMetric(self)

    def SetUseGradientType(self, gtype):
        r"""
        SetUseGradientType(self, gtype)

        Parameters
        ----------
        gtype: itk::ESMDemonsRegistrationFunctionEnums::Gradient

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_SetUseGradientType(self, gtype)

    def GetUseGradientType(self):
        r"""GetUseGradientType(self) -> itk::ESMDemonsRegistrationFunctionEnums::Gradient"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_GetUseGradientType(self)

    def SetUseFirstOrderExp(self, _arg):
        r"""
        SetUseFirstOrderExp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_SetUseFirstOrderExp(self, _arg)

    def GetUseFirstOrderExp(self):
        r"""GetUseFirstOrderExp(self) -> bool"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_GetUseFirstOrderExp(self)

    def UseFirstOrderExpOn(self):
        r"""UseFirstOrderExpOn(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_UseFirstOrderExpOn(self)

    def UseFirstOrderExpOff(self):
        r"""UseFirstOrderExpOff(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_UseFirstOrderExpOff(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_GetIntensityDifferenceThreshold(self)

    def SetMaximumUpdateStepLength(self, arg0):
        r"""
        SetMaximumUpdateStepLength(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_SetMaximumUpdateStepLength(self, arg0)

    def GetMaximumUpdateStepLength(self):
        r"""GetMaximumUpdateStepLength(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_GetMaximumUpdateStepLength(self)
    __swig_destroy__ = _itkDiffeomorphicDemonsRegistrationFilterPython.delete_itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22

        Create a new object of the class itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22 in _itkDiffeomorphicDemonsRegistrationFilterPython:
_itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22_swigregister(itkDiffeomorphicDemonsRegistrationFilterIF2IF2IVF22)

def itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_New():
    return itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33.New()

class itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIF3IF3IVF33):
    r"""Proxy of C++ itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_GetMetric(self)

    def SetUseGradientType(self, gtype):
        r"""
        SetUseGradientType(self, gtype)

        Parameters
        ----------
        gtype: itk::ESMDemonsRegistrationFunctionEnums::Gradient

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_SetUseGradientType(self, gtype)

    def GetUseGradientType(self):
        r"""GetUseGradientType(self) -> itk::ESMDemonsRegistrationFunctionEnums::Gradient"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_GetUseGradientType(self)

    def SetUseFirstOrderExp(self, _arg):
        r"""
        SetUseFirstOrderExp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_SetUseFirstOrderExp(self, _arg)

    def GetUseFirstOrderExp(self):
        r"""GetUseFirstOrderExp(self) -> bool"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_GetUseFirstOrderExp(self)

    def UseFirstOrderExpOn(self):
        r"""UseFirstOrderExpOn(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_UseFirstOrderExpOn(self)

    def UseFirstOrderExpOff(self):
        r"""UseFirstOrderExpOff(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_UseFirstOrderExpOff(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_GetIntensityDifferenceThreshold(self)

    def SetMaximumUpdateStepLength(self, arg0):
        r"""
        SetMaximumUpdateStepLength(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_SetMaximumUpdateStepLength(self, arg0)

    def GetMaximumUpdateStepLength(self):
        r"""GetMaximumUpdateStepLength(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_GetMaximumUpdateStepLength(self)
    __swig_destroy__ = _itkDiffeomorphicDemonsRegistrationFilterPython.delete_itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33

        Create a new object of the class itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33 in _itkDiffeomorphicDemonsRegistrationFilterPython:
_itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33_swigregister(itkDiffeomorphicDemonsRegistrationFilterIF3IF3IVF33)

def itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_New():
    return itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22.New()

class itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS2ISS2IVF22):
    r"""Proxy of C++ itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_GetMetric(self)

    def SetUseGradientType(self, gtype):
        r"""
        SetUseGradientType(self, gtype)

        Parameters
        ----------
        gtype: itk::ESMDemonsRegistrationFunctionEnums::Gradient

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_SetUseGradientType(self, gtype)

    def GetUseGradientType(self):
        r"""GetUseGradientType(self) -> itk::ESMDemonsRegistrationFunctionEnums::Gradient"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_GetUseGradientType(self)

    def SetUseFirstOrderExp(self, _arg):
        r"""
        SetUseFirstOrderExp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_SetUseFirstOrderExp(self, _arg)

    def GetUseFirstOrderExp(self):
        r"""GetUseFirstOrderExp(self) -> bool"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_GetUseFirstOrderExp(self)

    def UseFirstOrderExpOn(self):
        r"""UseFirstOrderExpOn(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_UseFirstOrderExpOn(self)

    def UseFirstOrderExpOff(self):
        r"""UseFirstOrderExpOff(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_UseFirstOrderExpOff(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_GetIntensityDifferenceThreshold(self)

    def SetMaximumUpdateStepLength(self, arg0):
        r"""
        SetMaximumUpdateStepLength(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_SetMaximumUpdateStepLength(self, arg0)

    def GetMaximumUpdateStepLength(self):
        r"""GetMaximumUpdateStepLength(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_GetMaximumUpdateStepLength(self)
    __swig_destroy__ = _itkDiffeomorphicDemonsRegistrationFilterPython.delete_itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22

        Create a new object of the class itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22 in _itkDiffeomorphicDemonsRegistrationFilterPython:
_itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22_swigregister(itkDiffeomorphicDemonsRegistrationFilterISS2ISS2IVF22)

def itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_New():
    return itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33.New()

class itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterISS3ISS3IVF33):
    r"""Proxy of C++ itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_GetMetric(self)

    def SetUseGradientType(self, gtype):
        r"""
        SetUseGradientType(self, gtype)

        Parameters
        ----------
        gtype: itk::ESMDemonsRegistrationFunctionEnums::Gradient

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_SetUseGradientType(self, gtype)

    def GetUseGradientType(self):
        r"""GetUseGradientType(self) -> itk::ESMDemonsRegistrationFunctionEnums::Gradient"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_GetUseGradientType(self)

    def SetUseFirstOrderExp(self, _arg):
        r"""
        SetUseFirstOrderExp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_SetUseFirstOrderExp(self, _arg)

    def GetUseFirstOrderExp(self):
        r"""GetUseFirstOrderExp(self) -> bool"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_GetUseFirstOrderExp(self)

    def UseFirstOrderExpOn(self):
        r"""UseFirstOrderExpOn(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_UseFirstOrderExpOn(self)

    def UseFirstOrderExpOff(self):
        r"""UseFirstOrderExpOff(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_UseFirstOrderExpOff(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_GetIntensityDifferenceThreshold(self)

    def SetMaximumUpdateStepLength(self, arg0):
        r"""
        SetMaximumUpdateStepLength(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_SetMaximumUpdateStepLength(self, arg0)

    def GetMaximumUpdateStepLength(self):
        r"""GetMaximumUpdateStepLength(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_GetMaximumUpdateStepLength(self)
    __swig_destroy__ = _itkDiffeomorphicDemonsRegistrationFilterPython.delete_itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33

        Create a new object of the class itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33 in _itkDiffeomorphicDemonsRegistrationFilterPython:
_itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33_swigregister(itkDiffeomorphicDemonsRegistrationFilterISS3ISS3IVF33)

def itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_New():
    return itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22.New()

class itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC2IUC2IVF22):
    r"""Proxy of C++ itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_GetMetric(self)

    def SetUseGradientType(self, gtype):
        r"""
        SetUseGradientType(self, gtype)

        Parameters
        ----------
        gtype: itk::ESMDemonsRegistrationFunctionEnums::Gradient

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_SetUseGradientType(self, gtype)

    def GetUseGradientType(self):
        r"""GetUseGradientType(self) -> itk::ESMDemonsRegistrationFunctionEnums::Gradient"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_GetUseGradientType(self)

    def SetUseFirstOrderExp(self, _arg):
        r"""
        SetUseFirstOrderExp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_SetUseFirstOrderExp(self, _arg)

    def GetUseFirstOrderExp(self):
        r"""GetUseFirstOrderExp(self) -> bool"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_GetUseFirstOrderExp(self)

    def UseFirstOrderExpOn(self):
        r"""UseFirstOrderExpOn(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_UseFirstOrderExpOn(self)

    def UseFirstOrderExpOff(self):
        r"""UseFirstOrderExpOff(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_UseFirstOrderExpOff(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_GetIntensityDifferenceThreshold(self)

    def SetMaximumUpdateStepLength(self, arg0):
        r"""
        SetMaximumUpdateStepLength(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_SetMaximumUpdateStepLength(self, arg0)

    def GetMaximumUpdateStepLength(self):
        r"""GetMaximumUpdateStepLength(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_GetMaximumUpdateStepLength(self)
    __swig_destroy__ = _itkDiffeomorphicDemonsRegistrationFilterPython.delete_itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22

        Create a new object of the class itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22 in _itkDiffeomorphicDemonsRegistrationFilterPython:
_itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22_swigregister(itkDiffeomorphicDemonsRegistrationFilterIUC2IUC2IVF22)

def itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_New():
    return itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33.New()

class itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33(itk.itkPDEDeformableRegistrationFilterPython.itkPDEDeformableRegistrationFilterIUC3IUC3IVF33):
    r"""Proxy of C++ itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_Pointer"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_Clone(self)

    def GetMetric(self):
        r"""GetMetric(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_GetMetric(self)

    def SetUseGradientType(self, gtype):
        r"""
        SetUseGradientType(self, gtype)

        Parameters
        ----------
        gtype: itk::ESMDemonsRegistrationFunctionEnums::Gradient

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_SetUseGradientType(self, gtype)

    def GetUseGradientType(self):
        r"""GetUseGradientType(self) -> itk::ESMDemonsRegistrationFunctionEnums::Gradient"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_GetUseGradientType(self)

    def SetUseFirstOrderExp(self, _arg):
        r"""
        SetUseFirstOrderExp(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_SetUseFirstOrderExp(self, _arg)

    def GetUseFirstOrderExp(self):
        r"""GetUseFirstOrderExp(self) -> bool"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_GetUseFirstOrderExp(self)

    def UseFirstOrderExpOn(self):
        r"""UseFirstOrderExpOn(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_UseFirstOrderExpOn(self)

    def UseFirstOrderExpOff(self):
        r"""UseFirstOrderExpOff(self)"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_UseFirstOrderExpOff(self)

    def SetIntensityDifferenceThreshold(self, arg0):
        r"""
        SetIntensityDifferenceThreshold(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_SetIntensityDifferenceThreshold(self, arg0)

    def GetIntensityDifferenceThreshold(self):
        r"""GetIntensityDifferenceThreshold(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_GetIntensityDifferenceThreshold(self)

    def SetMaximumUpdateStepLength(self, arg0):
        r"""
        SetMaximumUpdateStepLength(self, arg0)

        Parameters
        ----------
        arg0: double

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_SetMaximumUpdateStepLength(self, arg0)

    def GetMaximumUpdateStepLength(self):
        r"""GetMaximumUpdateStepLength(self) -> double"""
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_GetMaximumUpdateStepLength(self)
    __swig_destroy__ = _itkDiffeomorphicDemonsRegistrationFilterPython.delete_itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33

        Create a new object of the class itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33 in _itkDiffeomorphicDemonsRegistrationFilterPython:
_itkDiffeomorphicDemonsRegistrationFilterPython.itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33_swigregister(itkDiffeomorphicDemonsRegistrationFilterIUC3IUC3IVF33)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def diffeomorphic_demons_registration_filter(*args: itkt.ImageLike,  use_gradient_type=..., use_first_order_exp: bool=..., intensity_difference_threshold: float=..., maximum_update_step_length: float=..., fixed_image: itkt.Image=..., moving_image: itkt.Image=..., initial_displacement_field: itkt.Image=..., smooth_displacement_field: bool=..., standard_deviations: Union[float, Sequence[float]]=..., smooth_update_field: bool=..., update_field_standard_deviations: Union[float, Sequence[float]]=..., maximum_error: float=..., maximum_kernel_width: int=..., difference_function=..., number_of_iterations: int=..., use_image_spacing: bool=..., maximum_rms_error: float=..., rms_change: float=..., manual_reinitialization: bool=..., is_initialized: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for DiffeomorphicDemonsRegistrationFilter"""
    import itk

    kwarg_typehints = { 'use_gradient_type':use_gradient_type,'use_first_order_exp':use_first_order_exp,'intensity_difference_threshold':intensity_difference_threshold,'maximum_update_step_length':maximum_update_step_length,'fixed_image':fixed_image,'moving_image':moving_image,'initial_displacement_field':initial_displacement_field,'smooth_displacement_field':smooth_displacement_field,'standard_deviations':standard_deviations,'smooth_update_field':smooth_update_field,'update_field_standard_deviations':update_field_standard_deviations,'maximum_error':maximum_error,'maximum_kernel_width':maximum_kernel_width,'difference_function':difference_function,'number_of_iterations':number_of_iterations,'use_image_spacing':use_image_spacing,'maximum_rms_error':maximum_rms_error,'rms_change':rms_change,'manual_reinitialization':manual_reinitialization,'is_initialized':is_initialized }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.DiffeomorphicDemonsRegistrationFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def diffeomorphic_demons_registration_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKPDEDeformableRegistration.DiffeomorphicDemonsRegistrationFilter
    diffeomorphic_demons_registration_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    diffeomorphic_demons_registration_filter.__doc__ = filter_object.__doc__



